@@ -5,6 +5,7 @@ import importlib
 import logging
 from fontTools.misc.py23 import SimpleNamespace
 from fontTools.misc.loggingTools import Timer
+from ufo2ft.util import _LazyFontName, _GlyphSet
 
 
 UFO2FT_FILTERS_KEY = "com.github.googlei18n.ufo2ft.filters"
@@ -187,8 +188,10 @@ class BaseFilter(object):
         Otherwise, run the filter in-place on the font's default
         glyph set.
         """
+        logger.info("Running %s on %s", self.name, _LazyFontName(font))
+
         if glyphSet is None:
-            glyphSet = font
+            glyphSet = _GlyphSet.from_layer(font)
 
         context = self.set_context(font, glyphSet)
 
