@@ -1,9 +1,10 @@
 from __future__ import (
     print_function, division, absolute_import, unicode_literals)
 
+from fontTools.misc.py23 import basestring
 from ufo2ft.filters import loadFilters
 from ufo2ft.filters.decomposeComponents import DecomposeComponentsFilter
-from ufo2ft.util import copyGlyphSet
+from ufo2ft.util import _GlyphSet
 
 
 class BasePreProcessor(object):
@@ -27,13 +28,11 @@ class BasePreProcessor(object):
     "com.github.googlei18n.ufo2ft.filters".
     """
 
-    def __init__(self, ufo, inplace=False, **kwargs):
+    def __init__(self, ufo, inplace=False, layerName=None, **kwargs):
         self.ufo = ufo
         self.inplace = inplace
-        if inplace:
-            self.glyphSet = {g.name: g for g in ufo}
-        else:
-            self.glyphSet = copyGlyphSet(ufo)
+        self.layerName = layerName
+        self.glyphSet = _GlyphSet.from_layer(ufo, layerName, copy=not inplace)
         self.defaultFilters = self.initDefaultFilters(**kwargs)
         self.preFilters, self.postFilters = loadFilters(ufo)
 
@@ -55,13 +54,26 @@ class OTFPreProcessor(BasePreProcessor):
 
     If ``removeOverlaps`` is True, it performs a union boolean operation on
     all the glyphs' contours.
+
+    By default, booleanOperations is used to remove overlaps. You can choose
+    skia-pathops by setting ``overlapsBackend`` to the enum value
+    ``RemoveOverlapsFilter.SKIA_PATHOPS``, or the string "pathops".
     """
 
-    def initDefaultFilters(self, removeOverlaps=False):
+    def initDefaultFilters(
+        self, removeOverlaps=False, overlapsBackend=None
+    ):
         filters = [DecomposeComponentsFilter()]
         if removeOverlaps:
             from ufo2ft.filters.removeOverlaps import RemoveOverlapsFilter
-            filters.append(RemoveOverlapsFilter())
+
+            if overlapsBackend is not None:
+                filters.append(
+                    RemoveOverlapsFilter(backend=overlapsBackend)
+                )
+            else:
+                filters.append(RemoveOverlapsFilter())
+
         return filters
 
 
@@ -74,6 +86,10 @@ class TTFPreProcessor(OTFPreProcessor):
     If ``removeOverlaps`` is True, it performs a union boolean operation on
     all the glyphs' contours.
 
+    By default, booleanOperations is used to remove overlaps. You can choose
+    skia-pathops by setting ``overlapsBackend`` to the enum value
+    ``RemoveOverlapsFilter.SKIA_PATHOPS``, or the string "pathops".
+
     By default, it also converts all the PostScript cubic Bezier curves to
     TrueType quadratic splines. If the outlines are already quadratic, you
     can skip this by setting ``convertCubics`` to False.
@@ -95,16 +111,28 @@ class TTFPreProcessor(OTFPreProcessor):
     already set to "quadratic".
     """
 
-    def initDefaultFilters(self, removeOverlaps=False, convertCubics=True,
-                           conversionError=None, reverseDirection=True,
-                           rememberCurveType=True):
+    def initDefaultFilters(
+        self,
+        removeOverlaps=False,
+        overlapsBackend=None,
+        convertCubics=True,
+        conversionError=None,
+        reverseDirection=True,
+        rememberCurveType=True
+    ):
         # len(g) is the number of contours, so we include the all glyphs
         # that have both components and at least one contour
         filters = [DecomposeComponentsFilter(include=lambda g: len(g))]
 
         if removeOverlaps:
             from ufo2ft.filters.removeOverlaps import RemoveOverlapsFilter
-            filters.append(RemoveOverlapsFilter())
+
+            if overlapsBackend is not None:
+                filters.append(
+                    RemoveOverlapsFilter(backend=overlapsBackend)
+                )
+            else:
+                filters.append(RemoveOverlapsFilter())
 
         if convertCubics:
             from ufo2ft.filters.cubicToQuadratic import CubicToQuadraticFilter
@@ -135,15 +163,22 @@ class TTFInterpolatablePreProcessor(object):
     """
 
     def __init__(self, ufos, inplace=False, conversionError=None,
-                 reverseDirection=True, rememberCurveType=True):
+                 reverseDirection=True, rememberCurveType=True,
+                 layerNames=None):
         from cu2qu.ufo import DEFAULT_MAX_ERR
 
         self.ufos = ufos
         self.inplace = inplace
-        if inplace:
-            self.glyphSets = [{g.name: g for g in ufo} for ufo in ufos]
-        else:
-            self.glyphSets = [copyGlyphSet(ufo) for ufo in ufos]
+
+        if layerNames is None:
+            layerNames = [None] * len(ufos)
+        assert len(ufos) == len(layerNames)
+        self.layerNames = layerNames
+
+        self.glyphSets = [
+            _GlyphSet.from_layer(ufo, layerName, copy=not inplace)
+            for ufo, layerName in zip(ufos, layerNames)
+        ]
         self._conversionErrors = [
             (conversionError or DEFAULT_MAX_ERR) * ufo.info.unitsPerEm
             for ufo in ufos]
@@ -154,7 +189,7 @@ class TTFInterpolatablePreProcessor(object):
         from cu2qu.ufo import fonts_to_quadratic
 
         fonts_to_quadratic(
-            self.ufos if self.inplace else self.glyphSets,
+            self.glyphSets,
             max_err=self._conversionErrors,
             reverse_direction=self._reverseDirection,
             dump_stats=True,
